@@ -48,7 +48,7 @@ CONFDIR = os.path.expanduser("~/").rstrip('/')
 if os.path.isdir(f"{CONFDIR}/.config"):
     CONFDIR += '/.config'
 CONFDIR += "/.pywebexec"
-COMMAND_ID = str(uuid.uuid4())
+term_command_id = str(uuid.uuid4())
 
 # In-memory cache for command statuses
 command_status_cache = {}
@@ -263,7 +263,7 @@ def daemon_d(action, pidfilepath, silent=False, hostname=None, args=None):
                     n -= 1
                 except ProcessLookupError:
                     return True
-            print("Failed to stop server", file=sys.stderr)    
+            print("Failed to stop server", file=sys.stderr)
             return True
     elif action == "status":
         status = pidfile.is_locked()
@@ -296,18 +296,18 @@ def start_term():
     os.chdir(CWD)
     start_time = datetime.now().isoformat()
     user = pwd.getpwuid(os.getuid())[0]
-    print(f"Starting terminal session for {user} : {COMMAND_ID}")
-    update_command_status(COMMAND_ID, {
+    print(f"Starting terminal session for {user} : {term_command_id}")
+    update_command_status(term_command_id, {
         'status': 'running',
         'command': 'term',
         'params': [user, os.ttyname(sys.stdout.fileno())],
         'start_time': start_time,
         'user': user
     })
-    output_file_path = get_output_file_path(COMMAND_ID)
+    output_file_path = get_output_file_path(term_command_id)
     res = script(output_file_path)
     end_time = datetime.now().isoformat()
-    update_command_status(COMMAND_ID, {
+    update_command_status(term_command_id, {
         'status': 'success',
         'end_time': end_time,
         'exit_code': res
@@ -323,8 +323,8 @@ def print_urls(command_id=None):
     if token:
         url_params = f"?token={token}"
     if command_id:
-        print(f"{protocol}://{hostname}:{args.port}/popup/{command_id}{url_params}")
-        print(f"{protocol}://{ip}:{args.port}/popup/{command_id}{url_params}")
+        print(f"{protocol}://{hostname}:{args.port}/dopopup/{command_id}{url_params}")
+        print(f"{protocol}://{ip}:{args.port}/dopopup/{command_id}{url_params}")
     else:
         print(f"{protocol}://{hostname}:{args.port}{url_params}")
         print(f"{protocol}://{ip}:{args.port}{url_params}")
@@ -459,9 +459,9 @@ def read_command_status(command_id):
 def sigwinch_passthrough(sig, data):
     s = struct.pack("HHHH", 0, 0, 0, 0)
     a = struct.unpack('hhhh', fcntl.ioctl(sys.stdout.fileno(), termios.TIOCGWINSZ, s))
-    global p, COMMAND_ID
+    global p, term_command_id
     p.setwinsize(a[0], a[1])
-    update_command_status(COMMAND_ID, {
+    update_command_status(term_command_id, {
         'rows': a[0],
         'cols': a[1],
     })
@@ -750,6 +750,25 @@ def list_executables():
 def popup(command_id):
     return render_template('popup.html', command_id=command_id)
 
+@app.route('/dopopup/<command_id>')
+def do_popup(command_id):
+    token = request.args.get('token', '')
+    token_param = f'?token={token}' if token else ''
+    return f"""
+    <html>
+    <head>
+        <script type="text/javascript">
+            window.onload = function() {{
+                window.open('/popup/{command_id}{token_param}', '_blank', 'width=1000,height=600');
+                window.close();
+            }};
+        </script>
+    </head>
+    <body>
+    </body>
+    </html>
+    """
+
 def main():
     global COMMAND_STATUS_DIR
     basef = f"{CONFDIR}/pywebexec_{args.listen}:{args.port}"
@@ -768,7 +787,7 @@ def main():
         sys.argv.remove("shareterm")
         with open(basef + ".log", "ab+") as log:
             pywebexec = subprocess.Popen([sys.executable] + sys.argv, stdout=log, stderr=log)
-            print_urls(COMMAND_ID)
+            print_urls(term_command_id)
             res = start_term()
             print("Stopping server")
             time.sleep(1)
